import requests


def get(updater_name):
    return github


MASTER_ARCHIVE = "https://github.com/github/gitignore/archive/master.zip"


def github(archive_url, latest_file):
    response = requests.get(archive_url, stream=True)
    total_length = response.headers.get('content-length')

    yield total_length

    with open(latest_file, "wb") as f:
        if total_length:
            downloaded = 0
            for chunk in response.iter_content(1024):
                f.write(chunk)
                downloaded += len(chunk)
                yield downloaded
        else:
           f.write(response.content)


import argparse


def parse(args):
    parser = argparse.ArgumentParser(description="Generates .gitignore files")
    subparsers = parser.add_subparsers(title='subcommands',
                                       help='valid genignore subcommands',
                                       dest="action")

    gen_parser = subparsers.add_parser('gen', help='generate a gitignore')


    gen_parser.add_argument('names', metavar='N', type=str, nargs='+',
                            help='Name(s) of things to include to the .gitignore')

    gen_parser.add_argument("-o", "--out", type=str, default='',
                            help='file to output the generated gitignore (default .gitignore of pwd)')

    gen_parser.add_argument("--update", action='store_true',
                            help='update the file if it exists, keeping custom entries')

    gen_parser.add_argument("--add", action='store_true', default=False,
                            help='add templates the file if it exists, keeping previous entries')

    sync_parser = subparsers.add_parser("sync", help='sync to latest templates (requires internet connection)')

    list_parser = subparsers.add_parser("list", help="list all available templates")

    return parser.parse_args(args)



import sys
from clint.textui import puts
from clint.textui import colored
from clint.textui import progress
from clint.textui import columns


TTY_COLUMN_SIZE = 80


isatty = lambda : sys.stdout.isatty()


def print_colored(txt, color):
    if isatty():
        puts(color(txt))


print_error = lambda txt: print_colored(txt, colored.red)

print_notice = lambda txt: print_colored(txt, colored.yellow)

print_success = lambda txt: print_colored(txt, colored.green)


def print_list(names, title=None):
    if title:
        print_notice('Available Templates:')
    puts(columns([", ".join(names), TTY_COLUMN_SIZE]))
